Stan Math Library: stan/math/rev/core/std_numeric_limits.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
std_numeric_limits.hpp File Reference
`#include <stan/math/rev/core/var.hpp>`
`#include <limits>`

Go to the source code of this file.

## Classes
struct | std::numeric_limits< stan::math::var >
| Specialization of numeric limits for var objects. More...

## Namespaces
| std

[ Stan Home Page ] © 2011–2016, Stan Development Team.